==> libxfce4util-4.0.5.tar.bz2: libxfce4util-4.0.5/libxfce4util/libxfce4util-config.h <==
/* $Id: libxfce4util-config.h.in,v 1.1.2.1 2004/03/20 13:07:54 benny Exp $ */
/*-
 * Copyright (c) 2003,2004 Benedikt Meurer <benny@xfce.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __LIBXFCE4UTIL_LIBXFCE4UTIL_CONFIG_H__
#define __LIBXFCE4UTIL_LIBXFCE4UTIL_CONFIG_H__

#include <glib.h>

G_BEGIN_DECLS;

#define LIBXFCE4UTIL_MAJOR_VERSION	4
#define LIBXFCE4UTIL_MINOR_VERSION	0
#define LIBXFCE4UTIL_MICRO_VERSION	5

#define LIBXFCE4UTIL_CHECK_VERSION(major,minor,micro) \
  (LIBXFCE4UTIL_MAJOR_VERSION > (major) \
   || (LIBXFCE4UTIL_MAJOR_VERSION == (major) \
       && LIBXFCE4UTIL_MINOR_VERSION > (minor)) \
   || (LIBXFCE4UTIL_MAJOR_VERSION == (major) \
       && LIBXFCE4UTIL_MINOR_VERSION == (minor) \
       && LIBXFCE4UTIL_MICRO_VERSION >= (micro)))

G_END_DECLS;

#endif	/* !__LIBXFCE4UTIL_LIBXFCE4UTIL_CONFIG_H__ */

==> libxfce4util-4.2.0.tar.bz2: libxfce4util-4.2.0/libxfce4util/libxfce4util-config.h <==
/* $Id: libxfce4util-config.h.in,v 1.1 2004/03/01 22:50:36 benny Exp $ */
/*-
 * Copyright (c) 2003,2004 Benedikt Meurer <benny@xfce.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __LIBXFCE4UTIL_LIBXFCE4UTIL_CONFIG_H__
#define __LIBXFCE4UTIL_LIBXFCE4UTIL_CONFIG_H__

#ifndef __LIBXFCE4UTIL_LIBXFCE4UTIL_H__
#error  "Do not include <libxfce4util/libxfce4util-config.h> directly. Include <libxfce4util/libxfce4util.h> instead."
#endif

#include <glib.h>

G_BEGIN_DECLS;

#define LIBXFCE4UTIL_MAJOR_VERSION	4
#define LIBXFCE4UTIL_MINOR_VERSION	2
#define LIBXFCE4UTIL_MICRO_VERSION	0

#define LIBXFCE4UTIL_CHECK_VERSION(major,minor,micro) \
  (LIBXFCE4UTIL_MAJOR_VERSION > (major) \
   || (LIBXFCE4UTIL_MAJOR_VERSION == (major) \
       && LIBXFCE4UTIL_MINOR_VERSION > (minor)) \
   || (LIBXFCE4UTIL_MAJOR_VERSION == (major) \
       && LIBXFCE4UTIL_MINOR_VERSION == (minor) \
       && LIBXFCE4UTIL_MICRO_VERSION >= (micro)))

G_END_DECLS;

#endif	/* !__LIBXFCE4UTIL_LIBXFCE4UTIL_CONFIG_H__ */
